( cd usr/lib/gcc-lib/i486-slackware-linux/3.3.1/adalib ; rm -rf libgnarl.so )
( cd usr/lib/gcc-lib/i486-slackware-linux/3.3.1/adalib ; ln -sf libgnarl-*.so libgnarl.so )
( cd usr/lib/gcc-lib/i486-slackware-linux/3.3.1/adalib ; rm -rf libgnat.so )
( cd usr/lib/gcc-lib/i486-slackware-linux/3.3.1/adalib ; ln -sf libgnat-*.so libgnat.so )
